#
# spec file for package python-pymod2pkg
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname pymod2pkg
Name:           python-pymod2pkg
Version:        0.13.1
Release:        lp151.2.3
Summary:        OpenStack Packaging - python module name to package name map
License:        Apache-2.0
Group:          Development/Libraries/Python
Url:            https://wiki.openstack.org/wiki/Rpm-packaging
Source0:        https://files.pythonhosted.org/packages/source/p/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-devel
BuildRequires:  python-pbr
BuildRequires:  python-testrepository
BuildRequires:  python-testscenarios
BuildRequires:  python-testtools
Requires:       python-pbr
BuildArch:      noarch

%description
pymod2pkg is a simple python module for translating python module names to
corresponding package names which is a common problem in the packaging world.

%package doc
Summary:        Documentation for python module name to package name map library
Group:          Development/Libraries/Python
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx
Requires:       %{name} = %{version}

%description doc
Documentation for python module name to package name map library.

%prep
%autosetup -n %{sname}-%{version}
%py_req_cleanup

%build
%{py2_build}
# generate html docs
%{__python2} setup.py build_sphinx
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py2_install}

%check
%{__python2} setup.py test

%files
%license LICENSE
%doc README*
%{_bindir}/pymod2pkg
%{python2_sitelib}/%{sname}*
%{python2_sitelib}/*.egg-info

%files doc
%doc doc/build/html
%license LICENSE

%changelog
* Fri Feb  9 2018 cloud-devel@suse.de
- update to version 0.13.1
  - Fix the name for freezer-web-ui
  - Add RDO mapping for APScheduler
* Wed Feb  7 2018 cloud-devel@suse.de
- update to version 0.13.0
  - Add packages needed for freezer
  - Add freezer-api and freezer-dr services
  - Updated from global requirements
* Tue Jan  2 2018 cloud-devel@suse.de
- update to version 0.11.0
  - Change default translation for py2 in RDO
  - Add RDO mapping for sysv_ipc
  - Switch to newer flake8 / python 3.x version
  - Avoid tox_install.sh for constraints support
  - Add freezer for SUSE and RDO
  - Updated from global requirements
* Wed Oct 11 2017 cloud-devel@suse.de
- update to version 0.10.1
  - Fix mappings for os-brick and mock
  - Add tripleo-common for RDO openstack- packages
  - add a number of simple mappings for RDO
* Wed Sep 13 2017 cloud-devel@suse.de
- update to version 0.10.0
  - Add SUSE exception for python-devel
  - Add mapping for unversioned names
* Tue Sep 12 2017 cloud-devel@suse.de
- update to version 0.9.0
  - Added name conversion support for tempest-plugin
  - Support FWaaS/VPNaaS horizon ui/dashboard plugins on SUSE
  - Add mapping of PyJWT for RDO
  - Add mapping of tempest-horizon for RDO
  - Add support for python3 packages
  - Updated from global requirements
* Tue Aug  1 2017 cloud-devel@suse.de
- update to version 0.8.3
  - Add mappings for monasca-transform and monasca-ceilometer
* Thu Jul 27 2017 cloud-devel@suse.de
- update to version 0.8.2
  - Add RDO and SUSE mappings for karbor
  - Update home-page according to doc migration
* Wed Jul 26 2017 cloud-devel@suse.de
- update to version 0.8.1
  - Fix SUSE mapping for libvirt-python
  - Add SUSE naming exception for ansible
  - Updated from global requirements
* Fri Jun  2 2017 cloud-devel@suse.de
- update to version 0.7.8
  - Drop py34 and add py35 in setup.cfg tox.ini
  - Add murano-dashboard rule
  - Updated from global requirements
  - Add mappings for networking-vsphere
  - Add rule for GitPython in RDO
* Thu May 18 2017 cloud-devel@suse.de
- update to version 0.7.7:
  - Add mappings for libvirt-python
* Wed Apr 26 2017 cloud-devel@suse.de
- update to version 0.7.6
  - Add mappings for masakari
  - Updated from global requirements
* Thu Apr 13 2017 cloud-devel@suse.de
- update to version 0.7.5
  - Change horizon mapping for RDO
* Thu Apr  6 2017 cloud-devel@suse.de
- update to version 0.7.4:
  - Correctly translate horizon for SUSE
  - Add RDO mapping rules for dnspython and xattr
  - Support horizon ui/dashboard plugins on SUSE
  - Translate python-glareclient for SUSE correctly
  - Add monasca projects as OpenStack projects
  - Updated from global requirements
  - Fix RDO mapping for pyScss
  - Add RDO mappings for pyscss, XStatic-term.js and nosexcover
* Mon Feb 20 2017 cloud-devel@suse.de
- update to version 0.7.2:
  - Fix mapping of pystache for RDO
  - Add RDO mapping for bandit
  - Add RDO rule for PyPi package ovs
* Fri Feb 10 2017 cloud-devel@suse.de
- update to version 0.7.1:
  - Add RDO mapping for supervisor
  - Add upstream rule for XStatic-smart-table
  - Add support for Ubuntu
  - Fix RDO mistral mapping
  - Add Constraints support
* Fri Dec 23 2016 cloud-devel@suse.de
- update to version 0.7.0:
  - Set proper XStatic mapping for RDO
  - [SUSE] Avoid double adding of "python" for python-ldap
  - Add SUSE mapping for mistral
  - Add upstream mapping rule for microversion_parse
  - Delete duplicate k8s mapping
  - Show team and repo badges on README
  - Changed the home-page link
  - Add mapping for Sphinx in RDO
  - Updated from global requirements
* Sun Oct  9 2016 dmueller@suse.com
- update to 0.6.0:
  * Fix cloudkittyclient to cloudkitty
  * Updated from global requirements
  * More exceptions for python-*client naming on SUSE
  * Updated from global requirements
  * Add additional mappings for new clients
  * Add mapping for OpenStack project names
* Tue Sep 27 2016 dmueller@suse.com
- add  0001-More-exceptions-for-python-client-naming-on-SUSE.patch
* Thu Sep 22 2016 dmueller@suse.com
- Add 0001-Add-additional-mappings-for-new-clients.patch
* Thu Sep  8 2016 tbechtold@suse.com
- update to 0.5.4:
  * Set proper package name for mistral in RDO
  * Remove aodh/gnocchiclient remapping
  * pypi name is Tempest, not tempest
* Tue Aug 30 2016 tbechtold@suse.com
- update to 0.5.3:
  * Use the proper name for pyOpenSSL in RDO
  * Add python-ironic-inspector-client exception for SUSE
  * Add python-cinderclient exceptions for SUSE case
  * Fix pika-pool translation for RDO
* Tue Aug  9 2016 tbechtold@suse.com
- update to 0.5.2:
  * RDO: add missing wsgi_intercept translation
  * Add more python-*client exceptions for SUSE case
* Mon Jul 25 2016 tbechtold@suse.com
- update to 0.5.1:
  * Add more exceptions for SUSE case
  * RDO: add mapping for suds-jurko
  * Add RDO horizon plugins mapping
  * Add a RegexRule TranslationRule class
  * Add missing RDO mapping
  * Update RDO services mapping
  * Updated from global requirements
* Thu Jun  9 2016 tbechtold@suse.com
- update to 0.4.0:
  * Move main class to own folder
  * Switch to pbr for building pymod2pkg
  * Updated from global requirements
  * Add pymod2pkg executable
  * Update from global requirements
  * Add Fedora/RDO rules for PyMySQL and MySQL-python
  * Add RDO rule for pyinotify
  * Deprecated tox -downloadcache option removed
  * Add licensing header
  * Restructure documentation
  * Fix py34 DB issue
  * Add tox.ini to be able to run tests
* Mon Sep 14 2015 tbechtold@suse.com
- Initial packaging (version 0.3)
